// ---------------------------------------------------------------------------
// - t_module.cpp                                                            -
// - afnix engine - module tester module                                     -
// ---------------------------------------------------------------------------
// - This program is free software;  you can redistribute it  and/or  modify -
// - it provided that this copyright notice is kept intact.                  -
// -                                                                         -
// - This program  is  distributed in  the hope  that it will be useful, but -
// - without  any  warranty;  without  even   the   implied    warranty   of -
// - merchantability or fitness for a particular purpose.  In no event shall -
// - the copyright holder be liable for any  direct, indirect, incidental or -
// - special damages arising in any way out of the use of this software.     -
// ---------------------------------------------------------------------------
// - copyright (c) 1999-2023 amaury darsch                                   -
// ---------------------------------------------------------------------------

#include "Module.hpp"

int main (int, char**) {
  using namespace afnix;

  // create a default module
  Module md;
  if (md.repr () != "Module") return 1;

  // check for none
  if (md.istext () == true) return 1;
  if (md.getmfmt () != Module::MFMT_NONE) return 1;

  // success
  return 0;
}
